package File::Path::Set;

use warnings;
use strict;

use File::Spec::Functions qw/splitpath splitdir catdir catfile rootdir/;

=head1 NAME

File::Path::Set - Return a set of files along a path

=head1 VERSION

Version 0.03

=cut

our $VERSION = '0.03';

=head1 SYNOPSIS

This module finds all readable files along a defined path, possibly ignoring a base path.

    use File::Path::Set;

    my $foo = File::Path::Set->new(base => '/import/www', file => 'config.inc');
    $foo->file_set('/import/www/people/dom/bar/');

=head1 METHODS

=head2 new()

Returns a new File::Path::Set object. Only required parameter is file which defines the filename to adjoin to the path. Other paramters are base, the directory base to ignore and the boolean paramter readable. If readable is true, the file is only returned if it's readable. This defaults to true.

=cut

sub new {
	my ($class,%params) = @_;
	return undef unless defined($params{file});
	$params{base} =~ s,/$,, if $params{base};
	$params{readable} = 1 unless defined($params{readable});
	return bless { %params }, $class;
}


=head2 file_set($path)

Returns an array of readable files along $path or a reference to that array in scalar context.

=cut

sub file_set {
	my ($self,$path) = @_;
	my($vol,$dirs,$file) = splitpath($path);
	$dirs =~ s,/$,,;
	$dirs =~ s,^$self->{base},., if $self->{base};
	#my @dirs = grep {$_} splitdir($dirs);
	my @dirs = splitdir($dirs);

	my $search_path = $self->{base} || rootdir();
	my @file_set;
	foreach my $dir (@dirs) {
		$search_path = catdir($search_path, $dir);
		my $file = catfile($search_path,$self->{file});
		push @file_set, $file if -r $file || !$self->{readable};
	}
	return wantarray ? @file_set : \@file_set;
}

=head1 AUTHOR

Mario Domgoergen, C<< <dom at math.uni-bonn.de> >>

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc File::Path::Set


You can also look for information at:

=head1 COPYRIGHT & LICENSE

Copyright 2008 Mario Domgoergen, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut

1; # End of File::Path::Set
